@@ -360,17 +360,27 @@ class attributes:
             self.ax.tick_params(axis='y', labelsize=self.y_tick_label_size+self.font_size_increase)
         elif not isinstance(self.tick_label_size, type(None)):
             self.ax.tick_params(axis='y', labelsize=self.tick_label_size+self.font_size_increase)
-        #   Number and custom position ---------------------------------------------------------------------------------
-        if not isinstance(self.x_tick_number, type(None)):
-            self.ax.set_xticks(np.linspace(
-                self.x_tick_labels[0] if not isinstance(self.x_tick_labels, type(None)) else self.ax.get_xlim()[0],
-                self.x_tick_labels[1] if not isinstance(self.x_tick_labels, type(None)) else self.ax.get_xlim()[1],
-                self.x_tick_number))
-        if not isinstance(self.y_tick_number, type(None)):
-            self.ax.set_yticks(np.linspace(
-                self.y_tick_labels[0] if not isinstance(self.y_tick_labels, type(None)) else self.ax.get_ylim()[0],
-                self.y_tick_labels[1] if not isinstance(self.y_tick_labels, type(None)) else self.ax.get_ylim()[1],
-                self.y_tick_number))
+        #   Custom tick positions
+        if not isinstance(self.x_custom_tick_locations, type(None)):
+            high = self.x_custom_tick_locations[0]
+            low = self.x_custom_tick_locations[1]
+            # Set usual ticks
+            if self.x_tick_number > 1:
+                ticklocs = np.linspace(low, high, self.x_tick_number)
+            # Special case: single tick
+            else:
+                ticklocs = np.array([low + (high - low) / 2])
+            self.ax.set_xticks(ticklocs)
+        if not isinstance(self.y_custom_tick_locations, type(None)):
+            high = self.y_custom_tick_locations[0]
+            low = self.y_custom_tick_locations[1]
+            # Set usual ticks
+            if self.y_tick_number > 1:
+                ticklocs = np.linspace(low, high, self.y_tick_number)
+            # Special case: single tick
+            else:
+                ticklocs = np.array([low + (high - low) / 2])
+            self.ax.set_yticks(ticklocs)
         #   Prune
         if not isinstance(self.prune, type(None)):
             self.ax.xaxis.set_major_locator(self.plt.MaxNLocator(prune=self.prune))
@@ -385,17 +395,6 @@ class attributes:
         float_format_y = '%.' + str(y_decimals) + 'f'
         self.ax.xaxis.set_major_formatter(FormatStrFormatter(float_format_x))
         self.ax.yaxis.set_major_formatter(FormatStrFormatter(float_format_y))
-        #   Custom tick positions
-        if not isinstance(self.x_custom_tick_locations, type(None)):
-            self.ax.set_xticks(np.linspace(self.x_custom_tick_locations[0],
-                                           self.x_custom_tick_locations[1],
-                                           self.x_tick_number),
-                               )
-        if not isinstance(self.y_custom_tick_locations, type(None)):
-            self.ax.set_yticks(np.linspace(self.y_custom_tick_locations[0],
-                                           self.y_custom_tick_locations[1],
-                                           self.y_tick_number),
-                               )
         #   Custom tick labels
         if not isinstance(self.x_custom_tick_labels, type(None)):
             if len(self.x_custom_tick_labels) == 2 and len(self.x_custom_tick_labels) != self.x_tick_number:
@@ -535,6 +534,8 @@ class line(plot, std_input):
     def __init__(self,
                  # Specifics
                  x=None, y=None, line_width=2,
+                 # Specifics: color
+                 color='darkred', cmap='RdBu_r', alpha=None, norm=None,
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
@@ -558,16 +559,14 @@ class line(plot, std_input):
                  y_upper_resize_pad=0, y_lower_resize_pad=0,
                  # Grid
                  grid=True, grid_color='lightgrey', grid_lines='-.',
-                 # Color
-                 color='darkred', cmap='RdBu_r', alpha=None, norm=None,
                  # Title
                  title=None, title_size=12, title_y=1.025, title_weight=None, title_font=None, title_color=None,
                  # Labels
                  x_label=None, x_label_size=12, x_label_pad=10, x_label_rotation=None, x_label_weight=None,
                  y_label=None, y_label_size=12, y_label_pad=10, y_label_rotation=None, y_label_weight=None,
                  # Ticks
-                 x_tick_number=5, x_tick_labels=None,
-                 y_tick_number=5, y_tick_labels=None,
+                 x_tick_number=5,
+                 y_tick_number=5,
                  x_label_coords=None, y_label_coords=None,
                  tick_color=None, tick_label_pad=5,
                  ticks_where=(1, 1, 0, 0),
@@ -608,6 +607,12 @@ class line(plot, std_input):
         :param y: y
         :param line_width: Line width
 
+        Color:
+        :param color: Solid color
+        :param cmap: Colormap
+        :param alpha: Alpha
+        :param norm: Norm to assign colormap values
+
         Other
         :param backend: Interactive plotting backends. Working with Python 3.7.6: Qt5Agg, QT4Agg, TkAgg.
                         Backend error:
@@ -663,6 +668,8 @@ class scatter(plot, std_input):
     def __init__(self,
                  # Specifics
                  x=None, y=None, point_size=5, marker='o',
+                 # Specifics: color
+                 color="C0", cmap='RdBu_r', alpha=None, norm=None,
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
@@ -686,16 +693,14 @@ class scatter(plot, std_input):
                  y_upper_resize_pad=0, y_lower_resize_pad=0,
                  # Grid
                  grid=True, grid_color='lightgrey', grid_lines='-.',
-                 # Color
-                 color="C0", cmap='RdBu_r', alpha=None, norm=None,
                  # Title
                  title=None, title_size=12, title_y=1.025, title_weight=None, title_font=None, title_color=None,
                  # Labels
                  x_label=None, x_label_size=12, x_label_pad=10, x_label_rotation=None, x_label_weight=None,
                  y_label=None, y_label_size=12, y_label_pad=10, y_label_rotation=None, y_label_weight=None,
                  # Ticks
-                 x_tick_number=5, x_tick_labels=None,
-                 y_tick_number=5, y_tick_labels=None,
+                 x_tick_number=5,
+                 y_tick_number=5,
                  x_label_coords=None, y_label_coords=None,
                  tick_color=None, tick_label_pad=5,
                  ticks_where=(1, 1, 0, 0),
@@ -737,6 +742,12 @@ class scatter(plot, std_input):
         :param point_size: Point size
         :param marker: Dot marker
 
+        Color:
+        :param color: Solid color
+        :param cmap: Colormap
+        :param alpha: Alpha
+        :param norm: Norm to assign colormap values
+
         Other
         :param backend: Interactive plotting backends. Working with Python 3.7.6: Qt5Agg, QT4Agg, TkAgg.
                         Backend error:
@@ -778,6 +789,8 @@ class heatmap(plot, df_input):
     def __init__(self,
                  # Specifics
                  x=None, y=None, z=None, normvariant='SymLog',
+                 # Specifics: color
+                 color=None, cmap='RdBu_r', alpha=None, norm=None,
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
@@ -801,16 +814,14 @@ class heatmap(plot, df_input):
                  y_upper_resize_pad=0, y_lower_resize_pad=0,
                  # Grid
                  grid=True, grid_color='lightgrey', grid_lines='-.',
-                 # Color
-                 color=None, cmap='RdBu_r', alpha=None, norm=None,
                  # Title
                  title=None, title_size=12, title_y=1.025, title_weight=None, title_font=None, title_color=None,
                  # Labels
                  x_label=None, x_label_size=12, x_label_pad=10, x_label_rotation=None, x_label_weight=None,
                  y_label=None, y_label_size=12, y_label_pad=10, y_label_rotation=None, y_label_weight=None,
                  # Ticks
-                 x_tick_number=5, x_tick_labels=None,
-                 y_tick_number=5, y_tick_labels=None,
+                 x_tick_number=5,
+                 y_tick_number=5,
                  x_label_coords=None, y_label_coords=None,
                  tick_color=None, tick_label_pad=5,
                  ticks_where=(1, 1, 0, 0),
@@ -852,6 +863,12 @@ class heatmap(plot, df_input):
         :param z: z
         :param normvariant: Detailed information in the Matplotlib documentation
 
+        Color:
+        :param color: Solid color
+        :param cmap: Colormap
+        :param alpha: Alpha
+        :param norm: Norm to assign colormap values
+
         Other
         :param backend: Interactive plotting backends. Working with Python 3.7.6: Qt5Agg, QT4Agg, TkAgg.
                         Backend error:
@@ -897,6 +914,8 @@ class quiver(plot, std_input):
     def __init__(self,
                  # Specifics
                  x=None, y=None, u=None, v=None,
+                 # Specifics: color
+                 color=None, cmap='RdBu_r', alpha=None, norm=None,
                  rule=None, custom_rule=None, vector_width=0.01, vector_min_shaft=2, vector_length_threshold=0.1,
                  # Backend
                  backend='Qt5Agg',
@@ -921,16 +940,14 @@ class quiver(plot, std_input):
                  y_upper_resize_pad=0, y_lower_resize_pad=0,
                  # Grid
                  grid=True, grid_color='lightgrey', grid_lines='-.',
-                 # Color
-                 color=None, cmap='RdBu_r', alpha=None, norm=None,
                  # Title
                  title=None, title_size=12, title_y=1.025, title_weight=None, title_font=None, title_color=None,
                  # Labels
                  x_label=None, x_label_size=12, x_label_pad=10, x_label_rotation=None, x_label_weight=None,
                  y_label=None, y_label_size=12, y_label_pad=10, y_label_rotation=None, y_label_weight=None,
                  # Ticks
-                 x_tick_number=5, x_tick_labels=None,
-                 y_tick_number=5, y_tick_labels=None,
+                 x_tick_number=5,
+                 y_tick_number=5,
                  x_label_coords=None, y_label_coords=None,
                  tick_color=None, tick_label_pad=5,
                  ticks_where=(1, 1, 0, 0),
@@ -978,6 +995,12 @@ class quiver(plot, std_input):
         :param vector_min_shaft: Minimum vector shaft
         :param vector_length_threshold: Minimum vector length
 
+        Color:
+        :param color: Solid color
+        :param cmap: Colormap
+        :param alpha: Alpha
+        :param norm: Norm to assign colormap values
+
         Other
         :param backend: Interactive plotting backends. Working with Python 3.7.6: Qt5Agg, QT4Agg, TkAgg.
                         Backend error:
@@ -1042,6 +1065,8 @@ class streamline(plot, std_input):
     def __init__(self,
                  # Specifics
                  x=None, y=None, u=None, v=None, line_width=1, line_density=2,
+                 # Specifics: color
+                 color=None, cmap='RdBu_r', alpha=None, norm=None,
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
@@ -1065,16 +1090,14 @@ class streamline(plot, std_input):
                  y_upper_resize_pad=0, y_lower_resize_pad=0,
                  # Grid
                  grid=True, grid_color='lightgrey', grid_lines='-.',
-                 # Color
-                 color=None, cmap='RdBu_r', alpha=None, norm=None,
                  # Title
                  title=None, title_size=12, title_y=1.025, title_weight=None, title_font=None, title_color=None,
                  # Labels
                  x_label=None, x_label_size=12, x_label_pad=10, x_label_rotation=None, x_label_weight=None,
                  y_label=None, y_label_size=12, y_label_pad=10, y_label_rotation=None, y_label_weight=None,
                  # Ticks
-                 x_tick_number=5, x_tick_labels=None,
-                 y_tick_number=5, y_tick_labels=None,
+                 x_tick_number=5,
+                 y_tick_number=5,
                  x_label_coords=None, y_label_coords=None,
                  tick_color=None, tick_label_pad=5,
                  ticks_where=(1, 1, 0, 0),
@@ -1119,6 +1142,12 @@ class streamline(plot, std_input):
         :param line_density: Measure of the amount of streamlines displayed. Low value (default=2)
 
 
+        Color:
+        :param color: Solid color
+        :param cmap: Colormap
+        :param alpha: Alpha
+        :param norm: Norm to assign colormap values
+
         Other
         :param backend: Interactive plotting backends. Working with Python 3.7.6: Qt5Agg, QT4Agg, TkAgg.
                         Backend error:
@@ -1170,6 +1199,8 @@ class fill_area(plot, std_input):
     def __init__(self,
                  # Specifics
                  x=None, y=None, z=None, between=False, below=False, above=False,
+                 # Specifics: color
+                 color=None, cmap='RdBu_r', alpha=None, norm=None,
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
@@ -1193,16 +1224,14 @@ class fill_area(plot, std_input):
                  y_upper_resize_pad=0, y_lower_resize_pad=0,
                  # Grid
                  grid=True, grid_color='lightgrey', grid_lines='-.',
-                 # Color
-                 color=None, cmap='RdBu_r', alpha=None, norm=None,
                  # Title
                  title=None, title_size=12, title_y=1.025, title_weight=None, title_font=None, title_color=None,
                  # Labels
                  x_label=None, x_label_size=12, x_label_pad=10, x_label_rotation=None, x_label_weight=None,
                  y_label=None, y_label_size=12, y_label_pad=10, y_label_rotation=None, y_label_weight=None,
                  # Ticks
-                 x_tick_number=5, x_tick_labels=None,
-                 y_tick_number=5, y_tick_labels=None,
+                 x_tick_number=5,
+                 y_tick_number=5,
                  x_label_coords=None, y_label_coords=None,
                  tick_color=None, tick_label_pad=5,
                  ticks_where=(1, 1, 0, 0),
@@ -1250,6 +1279,12 @@ class fill_area(plot, std_input):
         :param below: Fill below Curve 1 and Curve 2
         :param above: Fill above Curve 1 and Curve 2
 
+        Color:
+        :param color: Solid color
+        :param cmap: Colormap
+        :param alpha: Alpha
+        :param norm: Norm to assign colormap values
+
         Other
         :param backend: Interactive plotting backends. Working with Python 3.7.6: Qt5Agg, QT4Agg, TkAgg.
                         Backend error:
